@@ -5,8 +5,8 @@ from typing import Optional
 class ActionType(Enum):
     """Action types for XP24 telegrams"""
 
-    PRESS = "AA"  # Make action (activate relay)
-    RELEASE = "AB"  # Break action (deactivate relay)
+    OFF_PRESS = "AA"  # Make action (activate relay)
+    ON_RELEASE = "AB"  # Break action (deactivate relay)
 
     @classmethod
     def from_code(cls, code: str) -> Optional["ActionType"]:
