@@ -1,3 +1,5 @@
+from pathlib import Path
+
 from pydantic import BaseModel, IPvAnyAddress
 from typing import List, Optional
 
@@ -8,6 +10,7 @@ class ConsonModuleConfig(BaseModel):
     module_type: str
     module_type_code: int
     link_number: int
+    enabled: bool = True
     module_number: Optional[int] = None
     conbus_ip: Optional[IPvAnyAddress] = None
     conbus_port: Optional[int] = None
@@ -19,9 +22,9 @@ class ConsonModuleListConfig(BaseModel):
     root: List[ConsonModuleConfig]
 
     @classmethod
-    def from_yaml(cls, file_path: str) -> 'ConsonModuleListConfig':
+    def from_yaml(cls, file_path: str) -> "ConsonModuleListConfig":
         import yaml
-        with open(file_path, 'r') as file:
+
+        with Path(file_path).open("r") as file:
             data = yaml.safe_load(file)
         return cls(root=data)
-
