@@ -1,12 +1,13 @@
 from enum import Enum
 from typing import Optional
 
+
 class WriteConfigType(str, Enum):
     """Write Config types for system telegrams"""
 
     LINK_NUMBER = "04"
     MODULE_NUMBER = "05"
-    XP_FLAG_TELEGRAM = "06"
+    SYSTEM_TYPE = "06"  # 00 CP, 01 XP, 02 MIXED
 
     @classmethod
     def from_code(cls, code: str) -> Optional["WriteConfigType"]:
@@ -15,4 +16,3 @@ class WriteConfigType(str, Enum):
             if dp_type.value == code:
                 return dp_type
         return None
-
