@@ -4,13 +4,16 @@ This service implements a TCP client that connects to Conbus servers and sends
 various types of telegrams including discover, version, and sensor data requests.
 """
 
-import socket
 import logging
-import yaml
-import os
-from typing import List, Optional, Any
+import socket
 from datetime import datetime
+from pathlib import Path
+from typing import List, Optional, Any
 
+import yaml
+from typing_extensions import Callable
+
+from .conbus_connection_pool import ConbusConnectionPool
 from ..models import (
     ConbusClientConfig,
     ConbusRequest,
@@ -20,7 +23,6 @@ from ..models import (
 from ..models.response import Response
 from ..models.system_function import SystemFunction
 from ..utils.checksum import calculate_checksum
-from .conbus_connection_pool import ConbusConnectionPool
 
 
 class ConbusError(Exception):
@@ -41,7 +43,6 @@ class ConbusService:
         """Initialize the Conbus client send service"""
         self.config_path = config_path
         self.config = ConbusClientConfig()
-        self.socket: Optional[socket.socket] = None
         self.is_connected = False
         self.last_activity: Optional[datetime] = None
 
@@ -58,8 +59,8 @@ class ConbusService:
     def _load_config(self) -> None:
         """Load client configuration from cli.yml"""
         try:
-            if os.path.exists(self.config_path):
-                with open(self.config_path, "r") as file:
+            if Path(self.config_path).exists():
+                with Path(self.config_path).open("r") as file:
                     config_data = yaml.safe_load(file)
                     conbus_config = config_data.get("conbus", {})
 
@@ -116,7 +117,6 @@ class ConbusService:
         except Exception as e:
             self.logger.error(f"Error closing connection pool: {e}")
         finally:
-            self.socket = None
             self.is_connected = False
 
     def get_connection_status(self) -> ConbusConnectionStatus:
@@ -139,18 +139,18 @@ class ConbusService:
         start_pos = 0
         while True:
             # Find the start of next telegram
-            start_idx = raw_data.find('<', start_pos)
+            start_idx = raw_data.find("<", start_pos)
             if start_idx == -1:
                 break
 
             # Find the end of this telegram
-            end_idx = raw_data.find('>', start_idx)
+            end_idx = raw_data.find(">", start_idx)
             if end_idx == -1:
                 # Incomplete telegram at the end
                 break
 
             # Extract telegram including < and >
-            telegram = raw_data[start_idx:end_idx + 1]
+            telegram = raw_data[start_idx : end_idx + 1]
             if telegram.strip():
                 telegrams.append(telegram.strip())
 
@@ -158,54 +158,49 @@ class ConbusService:
 
         return telegrams
 
-    def _receive_responses(self) -> List[str]:
+    def receive_responses(
+        self,
+        timeout: float = 0.1,
+        receive_callback: Optional[Callable[[list[str]], None]] = None,
+    ) -> List[str]:
         """Receive responses from the server and properly split telegrams"""
-        accumulated_data = ""
+        import time
+
+        all_telegrams = []
+        start_time = time.time()
 
         try:
-            # Set a shorter timeout for receiving responses
-            if self.socket is None:
-                return []
-            original_timeout = self.socket.gettimeout()
-            self.socket.settimeout(0.1)  # 1 second timeout for responses
-
-            while True:
-                try:
-                    data = self.socket.recv(1024)
-                    if not data:
-                        break
-
-                    # Accumulate all received data
-                    message = data.decode("latin-1")
-                    accumulated_data += message
-                    self.last_activity = datetime.now()
-
-                except socket.timeout:
-                    # No more data available
-                    break
-
-            # Restore original timeout
-            if self.socket is not None:
-                self.socket.settimeout(original_timeout)
+            with self._connection_pool as connection:
+                while time.time() - start_time < timeout:
+                    # Call _receive_responses_with_connection with a short timeout for each iteration
+                    telegrams = self._receive_responses_with_connection(
+                        connection, timeout=0.1
+                    )
+                    if receive_callback is not None:
+                        receive_callback(telegrams)
+                    all_telegrams.extend(telegrams)
 
+                    # Small sleep to avoid busy waiting when no data
+                    time.sleep(0.01)
         except Exception as e:
             self.logger.error(f"Error receiving responses: {e}")
+            return []
 
-        # Parse telegrams from accumulated data
-        telegrams = self._parse_telegrams(accumulated_data)
-        for telegram in telegrams:
-            self.logger.info(f"Received telegram: {telegram}")
+        return all_telegrams
 
-        return telegrams
-
-    def _receive_responses_with_connection(self, connection: socket.socket, timeout: float = 1.0) -> List[str]:
+    def _receive_responses_with_connection(
+        self,
+        connection: socket.socket,
+        timeout: float = 1.0,
+        receive_callback: Optional[Callable[[list[str]], None]] = None,
+    ) -> List[str]:
         """Receive responses from the server using a specific connection"""
         accumulated_data = ""
 
         try:
             # Set a shorter timeout for receiving responses
             original_timeout = connection.gettimeout()
-            connection.settimeout(timeout)  # 2 second timeout for responses
+            connection.settimeout(timeout)  # 1 second timeout for responses
 
             while True:
                 try:
@@ -215,6 +210,9 @@ class ConbusService:
 
                     # Accumulate all received data
                     message = data.decode("latin-1")
+                    if receive_callback is not None:
+                        parsed_telegrams = self._parse_telegrams(message)
+                        receive_callback(parsed_telegrams)
                     accumulated_data += message
                     self.last_activity = datetime.now()
                     connection.settimeout(0.1)  # 2 second timeout for responses
@@ -237,7 +235,11 @@ class ConbusService:
         return telegrams
 
     def send_telegram(
-        self, serial_number: str, system_function: SystemFunction, data: str
+        self,
+        serial_number: str,
+        system_function: SystemFunction,
+        data: str,
+        receive_callback: Optional[Callable[[list[str]], None]] = None,
     ) -> ConbusResponse:
         """Send custom telegram with specified function and data point codes"""
         # Generate custom system telegram: <S{serial}F{function}{data_point}{checksum}>
@@ -246,19 +248,23 @@ class ConbusService:
         checksum = calculate_checksum(telegram_body)
         telegram = f"<{telegram_body}{checksum}>"
 
-        return  self.send_raw_telegram(telegram)
+        return self.send_raw_telegram(telegram, receive_callback)
 
     def send_telegram_body(
-        self, telegram_body: str
+        self,
+        telegram_body: str,
+        receive_callback: Optional[Callable[[list[str]], None]] = None,
     ) -> ConbusResponse:
         """Send custom telegram with specified function and data point codes"""
         checksum = calculate_checksum(telegram_body)
         telegram = f"<{telegram_body}{checksum}>"
 
-        return self.send_raw_telegram(telegram)
+        return self.send_raw_telegram(telegram, receive_callback)
 
     def send_raw_telegram(
-            self, telegram: Optional[str] = None
+        self,
+        telegram: Optional[str] = None,
+        receive_callback: Optional[Callable[[list[str]], None]] = None,
     ) -> ConbusResponse:
         """Send telegram using connection pool with automatic acquire/release"""
         request = ConbusRequest(telegram=telegram)
@@ -267,7 +273,7 @@ class ConbusService:
             # Use context manager for automatic connection management
             with self._connection_pool as connection:
 
-                # Receive waiting event if available (wait time 0)
+                # Draining event waiting to be read (wait time 0)
                 responses = self._receive_responses_with_connection(connection, 0.001)
                 self.logger.info(f"Purged telegram: {responses}")
 
@@ -280,7 +286,9 @@ class ConbusService:
                 self.is_connected = True  # Update connection status
 
                 # Receive responses
-                responses = self._receive_responses_with_connection(connection)
+                responses = self._receive_responses_with_connection(
+                    connection, 0.1, receive_callback
+                )
 
                 return ConbusResponse(
                     success=True,
@@ -305,11 +313,15 @@ class ConbusService:
         all_telegrams = "".join(telegrams)
         return self.send_raw_telegram(all_telegrams)
 
-    def __enter__(self) -> 'ConbusService':
+    def __enter__(self) -> "ConbusService":
         """Context manager entry"""
         return self
 
-    def __exit__(self, exc_type: Optional[type], exc_val: Optional[Exception], exc_tb: Optional[Any]) -> None:
+    def __exit__(
+        self,
+        _exc_type: Optional[type],
+        _exc_val: Optional[Exception],
+        _exc_tb: Optional[Any],
+    ) -> None:
         """Context manager exit - ensure connection is closed"""
         self.disconnect()
-
