@@ -156,8 +156,9 @@ class TelegramDiscoverService:
         # Discover response format: <R{10-digit-serial}F01D{2-char-checksum}>
         import re
 
-        pattern = re.compile(r"^<R(\d{10})F01D([A-Z0-9]{2})>$")
-        match = pattern.match(raw_telegram.strip())
+        match = re.compile(r"^<R(\d{10})F01D([A-Z0-9]{2})>$").match(
+            raw_telegram.strip()
+        )
 
         return match is not None
 
@@ -224,7 +225,7 @@ class TelegramDiscoverService:
         if summary["duplicate_responses"] > 0:
             lines.append(f"Duplicate Responses: {summary['duplicate_responses']}")
 
-        lines.append("\nDiscovered Devices:")
+        lines.extend("\nDiscovered Devices:")
         lines.append("-" * 40)
 
         for device in unique_devices:
