@@ -7,7 +7,10 @@ from xp.cli.main import cli
 from xp.models.conbus_datapoint import ConbusDatapointResponse
 from xp.models.datapoint_type import DataPointType
 from xp.models.system_function import SystemFunction
-from xp.services.conbus_datapoint_service import ConbusDatapointService, ConbusDatapointError
+from xp.services.conbus_datapoint_service import (
+    ConbusDatapointService,
+    ConbusDatapointError,
+)
 
 
 class TestConbusDatapointIntegration:
@@ -19,7 +22,7 @@ class TestConbusDatapointIntegration:
         self.valid_serial = "0123450001"
         self.invalid_serial = "invalid"
 
-    @patch('xp.cli.commands.conbus_datapoint_commands.ConbusDatapointService')
+    @patch("xp.cli.commands.conbus_datapoint_commands.ConbusDatapointService")
     def test_conbus_datapoint_all_valid_serial(self, mock_service_class):
         """Test querying all datapoints with valid serial number"""
 
@@ -39,15 +42,15 @@ class TestConbusDatapointIntegration:
                 {"SW_VERSION": "XP33LED_V0.04.01"},
                 {"AUTO_REPORT_STATUS": "AA"},
                 {"MODULE_STATE": "OFF"},
-                {"MODULE_OUTPUT_STATE": "xxxxx000"}
-            ]
+                {"MODULE_OUTPUT_STATE": "xxxxx000"},
+            ],
         )
         mock_service.query_all_datapoints.return_value = mock_response
 
         # Run CLI command
-        result = self.runner.invoke(cli, [
-            'conbus', 'datapoint', 'all', self.valid_serial
-        ])
+        result = self.runner.invoke(
+            cli, ["conbus", "datapoint", "all", self.valid_serial]
+        )
 
         # Debug output
         print(f"Exit code: {result.exit_code}")
@@ -58,14 +61,16 @@ class TestConbusDatapointIntegration:
         # Assertions
         assert '"success": true' in result.output
         assert result.exit_code == 0
-        mock_service.query_all_datapoints.assert_called_once_with(serial_number=self.valid_serial)
+        mock_service.query_all_datapoints.assert_called_once_with(
+            serial_number=self.valid_serial
+        )
 
         # Check the response content
         assert f'"serial_number": "{self.valid_serial}"' in result.output
         assert '"datapoints"' in result.output
         assert '"MODULE_TYPE": "XP33LED"' in result.output
 
-    @patch('xp.cli.commands.conbus_datapoint_commands.ConbusDatapointService')
+    @patch("xp.cli.commands.conbus_datapoint_commands.ConbusDatapointService")
     def test_conbus_datapoint_all_invalid_serial(self, mock_service_class):
         """Test querying all datapoints with invalid serial number"""
 
@@ -75,18 +80,20 @@ class TestConbusDatapointIntegration:
         mock_service.__enter__ = Mock(return_value=mock_service)
         mock_service.__exit__ = Mock(return_value=None)
 
-        mock_service.query_all_datapoints.side_effect = ConbusDatapointError("Invalid serial number")
+        mock_service.query_all_datapoints.side_effect = ConbusDatapointError(
+            "Invalid serial number"
+        )
 
         # Run CLI command
-        result = self.runner.invoke(cli, [
-            'conbus', 'datapoint', 'all', self.invalid_serial
-        ])
+        result = self.runner.invoke(
+            cli, ["conbus", "datapoint", "all", self.invalid_serial]
+        )
 
         # Should handle the error gracefully
         assert result.exit_code != 0
         assert "Invalid serial number" in result.output or "Error" in result.output
 
-    @patch('xp.cli.commands.conbus_datapoint_commands.ConbusDatapointService')
+    @patch("xp.cli.commands.conbus_datapoint_commands.ConbusDatapointService")
     def test_conbus_datapoint_connection_error(self, mock_service_class):
         """Test handling network connection failures"""
 
@@ -96,18 +103,20 @@ class TestConbusDatapointIntegration:
         mock_service.__enter__ = Mock(return_value=mock_service)
         mock_service.__exit__ = Mock(return_value=None)
 
-        mock_service.query_all_datapoints.side_effect = ConbusDatapointError("Connection failed")
+        mock_service.query_all_datapoints.side_effect = ConbusDatapointError(
+            "Connection failed"
+        )
 
         # Run CLI command
-        result = self.runner.invoke(cli, [
-            'conbus', 'datapoint', 'all', self.valid_serial
-        ])
+        result = self.runner.invoke(
+            cli, ["conbus", "datapoint", "all", self.valid_serial]
+        )
 
         # Should handle the error gracefully
         assert "Connection failed" in result.output or "Error" in result.output
         assert result.exit_code != 0
 
-    @patch('xp.cli.commands.conbus_datapoint_commands.ConbusDatapointService')
+    @patch("xp.cli.commands.conbus_datapoint_commands.ConbusDatapointService")
     def test_conbus_datapoint_invalid_response(self, mock_service_class):
         """Test handling invalid responses from the server"""
 
@@ -121,21 +130,21 @@ class TestConbusDatapointIntegration:
             success=False,
             serial_number=self.valid_serial,
             error="Invalid response from server",
-            datapoints=[]
+            datapoints=[],
         )
         mock_service.query_all_datapoints.return_value = mock_response
 
         # Run CLI command
-        result = self.runner.invoke(cli, [
-            'conbus', 'datapoint', 'all', self.valid_serial
-        ])
+        result = self.runner.invoke(
+            cli, ["conbus", "datapoint", "all", self.valid_serial]
+        )
 
         # Should return the failed response
         assert '"success": false' in result.output
         assert result.exit_code == 0  # CLI succeeds but response indicates failure
         assert "Invalid response from server" in result.output
 
-    @patch('xp.cli.commands.conbus_datapoint_commands.ConbusDatapointService')
+    @patch("xp.cli.commands.conbus_datapoint_commands.ConbusDatapointService")
     def test_conbus_datapoint_empty_datapoints(self, mock_service_class):
         """Test handling when no datapoints are returned"""
 
@@ -149,14 +158,14 @@ class TestConbusDatapointIntegration:
             success=True,
             serial_number=self.valid_serial,
             system_function=SystemFunction.READ_DATAPOINT,
-            datapoints=[]
+            datapoints=[],
         )
         mock_service.query_all_datapoints.return_value = mock_response
 
         # Run CLI command
-        result = self.runner.invoke(cli, [
-            'conbus', 'datapoint', 'all', self.valid_serial
-        ])
+        result = self.runner.invoke(
+            cli, ["conbus", "datapoint", "all", self.valid_serial]
+        )
 
         # Should succeed with empty datapoints
         assert '"success": true' in result.output
@@ -173,9 +182,11 @@ class TestConbusDatapointService:
         """Set up test fixtures"""
         self.valid_serial = "0123450001"
 
-    @patch('xp.services.conbus_datapoint_service.ConbusService')
-    @patch('xp.services.conbus_datapoint_service.TelegramService')
-    def test_query_all_datapoints_success(self, mock_telegram_service, mock_conbus_service):
+    @patch("xp.services.conbus_datapoint_service.ConbusService")
+    @patch("xp.services.conbus_datapoint_service.TelegramService")
+    def test_query_all_datapoints_success(
+        self, mock_telegram_service, mock_conbus_service
+    ):
         """Test successful querying of all datapoints"""
 
         # Mock dependencies
@@ -216,8 +227,8 @@ class TestConbusDatapointService:
         service = ConbusDatapointService()
 
         # Mock send_telegram to return success for some, failure for others
-        def mock_send_telegram(datapoint_type, serial_number):
-            if datapoint_type == DataPointType.MODULE_TYPE:
+        def mock_send_telegram(datapoint_type, _serial_number):
+            if datapoint_type == DataPointType.ERROR_CODE:
                 mock_reply = Mock()
                 mock_reply.data_value = "XP33LED"
 
@@ -241,5 +252,5 @@ class TestConbusDatapointService:
         assert result.success is True
         assert result.serial_number == self.valid_serial
         assert result.datapoints is not None
-        assert len(result.datapoints) == 1  # Only MODULE_TYPE succeeded
-        assert result.datapoints[0] == {"MODULE_TYPE": "XP33LED"}
\ No newline at end of file
+        assert len(result.datapoints) == 1  # Only ERROR_CODE succeeded
+        assert result.datapoints[0] == {"ERROR_CODE": "XP33LED"}
