@@ -177,6 +177,7 @@ class TestTelegramService:
         result = self.service.validate_checksum(telegram)
         assert result is False
 
+
 class TestSystemTelegramParsing:
     """Test cases for system telegram parsing in TelegramService"""
 
@@ -224,7 +225,7 @@ class TestSystemTelegramParsing:
         # Status data point
         raw = "<S0020012521F02D00FN>"
         result = self.service.parse_system_telegram(raw)
-        assert result.datapoint_type == DataPointType.MODULE_TYPE
+        assert result.datapoint_type == DataPointType.ERROR_CODE
 
     def test_parse_system_telegram_empty_string(self):
         """Test parsing empty string raises error"""
@@ -250,10 +251,9 @@ class TestSystemTelegramParsing:
         with pytest.raises(
             TelegramParsingError, match="Invalid system telegram format"
         ):
-            output = self.service.parse_system_telegram(
+            self.service.parse_system_telegram(
                 "<S0020012521F02D8FN>"
             )  # Wrong data point format
-            assert "cocou" in output.data
 
     def test_parse_system_telegram_unknown_function(self):
         """Test parsing system telegram with unknown function code"""
@@ -318,7 +318,7 @@ class TestReplyTelegramParsing:
         # Status reply
         raw = "<R0020012521F02D00OKIL>"
         result = self.service.parse_reply_telegram(raw)
-        assert result.datapoint_type == DataPointType.MODULE_TYPE
+        assert result.datapoint_type == DataPointType.ERROR_CODE
         assert result.data_value == "OK"
 
     def test_parse_reply_telegram_complex_data_values(self):
